==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_menus.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_menus.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("MENLAN_1", "Visible to all");
define("MENLAN_2", "Visible to members only");
define("MENLAN_3", "Visible to administrators only");
define("MENLAN_4", "Only visible to:");
// define("MENLAN_5", "class");
define("MENLAN_6", "Save visibility options");
define("MENLAN_7", "Configure visibility options for");
define("MENLAN_8", "Visibility options updated");
define("MENLAN_9", "New custom menu installed");
define("MENLAN_10", "New menu installed");
define("MENLAN_11", "Menu removed");
define("MENLAN_12", "Activate: choose area");
define("MENLAN_13", "Activate in Area");
define("MENLAN_14", "Area");
define("MENLAN_15", "Deactivate");
define("MENLAN_16", "Configure");
define("MENLAN_17", "Move Up");
define("MENLAN_18", "Move Down");
define("MENLAN_19", "Move to Area");
define("MENLAN_20", "Visibility");

// define("MENLAN_21", "Visible to Guests only");
define("MENLAN_22", "Inactive Menus");

define("MENLAN_23", "Move to bottom");
define("MENLAN_24", "Move to top");
define("MENLAN_25", "Function ...");

define("MENLAN_26", "This menu will only be <strong>SHOWN</strong> on the following pages");
define("MENLAN_27", "This menu will only be <strong>HIDDEN</strong> on the following pages");
define("MENLAN_28", "Enter one page per line, enter enough of the url to distinguish it properly.  If you need the ending of the url to match exactly, use a ! at the end of the page name <br />For example: <strong>page.php?1!</strong>");

define("MENLAN_29", "Select Layout");
define("MENLAN_30", "To see the menu areas and their positions for custom layouts, select the custom layout here:");
define("MENLAN_31", "Default Layout");
define("MENLAN_32", "Newsheader Layout");
define("MENLAN_33", "Custom Layout");
define("MENLAN_34", "Embedded");
define("MENLAN_35", "Configure Menus");
define("MENLAN_36", "Choose the menu(s) to activate");
define("MENLAN_37", "and where to activate them.");
define("MENLAN_38", "Hold down CTRL to select multiple menus.");


?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_menus.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_menus.php $
|     $Revision: 11678 $
|     $Id: lan_menus.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("MENLAN_1", "Visible to all");
define("MENLAN_2", "Visible to members only");
define("MENLAN_3", "Visible to administrators only");
define("MENLAN_4", "Only visible to:");
// define("MENLAN_5", "class");
define("MENLAN_6", "Save visibility options");
define("MENLAN_7", "Configure visibility options for");
define("MENLAN_8", "Visibility options updated");
define("MENLAN_9", "New custom menu installed");
define("MENLAN_10", "New menu installed");
define("MENLAN_11", "Menu removed");
define("MENLAN_12", "Activate: choose area");
define("MENLAN_13", "Activate in Area");
define("MENLAN_14", "Area");
define("MENLAN_15", "Deactivate");
define("MENLAN_16", "Configure");
define("MENLAN_17", "Move Up");
define("MENLAN_18", "Move Down");
define("MENLAN_19", "Move to Area");
define("MENLAN_20", "Visibility");

// define("MENLAN_21", "Visible to Guests only");
define("MENLAN_22", "Inactive Menus");

define("MENLAN_23", "Move to bottom");
define("MENLAN_24", "Move to top");
define("MENLAN_25", "Function ...");

define("MENLAN_26", "This menu will only be <strong>SHOWN</strong> on the following pages");
define("MENLAN_27", "This menu will only be <strong>HIDDEN</strong> on the following pages");
define("MENLAN_28", "Enter one page per line, enter enough of the url to distinguish it properly.  If you need the ending of the url to match exactly, use a ! at the end of the page name <br />For example: <strong>page.php?1!</strong>");

define("MENLAN_29", "Select Layout");
define("MENLAN_30", "To see the menu areas and their positions for custom layouts, select the custom layout here:");
define("MENLAN_31", "Default Layout");
define("MENLAN_32", "Newsheader Layout");
define("MENLAN_33", "Custom Layout");
define("MENLAN_34", "Embedded");
define("MENLAN_35", "Configure Menus");
define("MENLAN_36", "Choose the menu(s) to activate");
define("MENLAN_37", "and where to activate them.");
define("MENLAN_38", "Hold down CTRL to select multiple menus.");


?>
